mtest

package
v1.14.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2019 License: MIT Imports: 28 Imported by: 0

README

How to manually run CKE using placemat

  1. Run make setup

  2. Run make placemat

  3. Login to host1 by:

    $ chmod 600 mtest_key
    $ ./mssh host-1 
    
  4. Run /data/setup-cke.sh on host1.

  5. Run cke on host1.

  6. Copy /data/cluster.yml to $HOME, edit the copy, and load it by:

    $ /data/ckecli constraints set control-plane-count 3
    $ /data/ckecli cluster set $HOME/cluster.yml
    
  7. To stop placemat, run sudo pkill placemat.

If you want to use kubectl, run the following commands on host-vm.

```console
$ ./mssh host-1 /opt/bin/ckecli kubernetes issue > ~/.kube/config
$ ./output/kubectl get nodes
```

Documentation

Index

Constants

const (

	// DefaultRunTimeout is the timeout value for Agent.Run().
	DefaultRunTimeout = 10 * time.Minute
)

Variables

var FunctionsSuite = func() {
	Context("ckecli", TestCKECLI)
	Context("kubernetes", TestKubernetes)
}

FunctionsSuite is a test suite that tests small test cases

var OperatorsSuite = func() {
	Context("operators", TestOperators)
}

OperatorsSuite is a test suite that tests CKE operators

Functions

func RunBeforeSuite

func RunBeforeSuite()

RunBeforeSuite is for Ginkgo BeforeSuite

func TestCKECLI

func TestCKECLI()

TestCKECLI tests ckecli command

func TestKubernetes

func TestKubernetes()

TestKubernetes tests kubernetes workloads on CKE

func TestOperators

func TestOperators()

TestOperators tests all CKE operators

Types

This section is empty.

Jump to